Introduction
============

``humblewx`` is a Python library that makes it more pleasant to create user
interfaces with wxPython. It has two goals:

* Simplify writing code to construct and layout wxPython GUI components

* Enforce the `Humbe Dialog Box
  <http://www.objectmentor.com/resources/articles/TheHumbleDialogBox.pdf>`_
  pattern

``humblewx`` started life as a module in `The Timeline Project
<http://thetimelineproj.sourceforge.net/>`_. It was created because we wanted a
more pleasant way to work with all wxPython dialogs. It was later extracted to
its own library.
